<h1 align="center">onemetric</h1>

<p align="center"> 
    <img width="180" src=".//readme_figures/onemetric.png" alt="Logo">
</p>

## Installation

```terminal
pip install onemetric
```

## Contribute

Feel free to file [issues](https://github.com/SkalskiP/onemetric/issues) or [pull requests](https://github.com/SkalskiP/onemetric/pulls). 

## Citation

Please cite onemetric in your publications if this is useful for your research. Here is an example BibTeX entry:

```BibTeX
@MISC{onemetric,
   author = {Piotr Skalski},
   title = {{onemetric}},
   howpublished = "\url{https://github.com/SkalskiP/onemetric/}",
   year = {2021},
}
```

## License

This project is licensed under the BSD 3 - see the [LICENSE][1] file for details.

[1]: ./LICENSE
